@@ -1,17 +1,17 @@
-#$Id: SimpleLinkChecker.pm,v 1.4 2002/01/25 08:50:43 comdog Exp $
+#$Id: SimpleLinkChecker.pm,v 1.6 2004/09/08 02:20:42 comdog Exp $
 package HTTP::SimpleLinkChecker;
 use strict;
 
-use vars qw($UA $ERROR $VERSION @EXPORT_OK);
+use vars qw($ERROR $VERSION @EXPORT_OK);
 
 use HTTP::Request;
 use LWP::UserAgent;
 
 @EXPORT_OK = qw(check_link);
 
-$UA = LWP::UserAgent->new();
+my $UA = LWP::UserAgent->new();
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.4 $ =~ m/ (\d+) \. (\d+)/x;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.6 $ =~ m/ (\d+) \. (\d+)/x;
 
 sub check_link
 	{
@@ -21,14 +21,14 @@ sub check_link
 		$ERROR = 'Received no argument';
 		return;
 		}
-	
+
 	my $request = HTTP::Request->new('HEAD', $link);
 	unless( ref $request )
 		{
 		$ERROR = 'Could not create HEAD request';
 		return;
 		}
-	
+
 	my $response = $UA->request($request);
 
 	if( ref $response and $response->code >= 400 )
@@ -41,16 +41,21 @@ sub check_link
 			}
 		$response = $UA->request($request);
 		}
-	
+
 	unless( ref $response )
 		{
 		$ERROR = 'Could not get response';
 		return;
 		}
-	
+
 	return $response->code;
 	}
 
+sub user_agent
+	{
+	return $UA;
+	}
+
 1;
 
 =head1 NAME
@@ -75,7 +80,7 @@ Perl, LWP, or the HTTP module to be able to check your
 links. This module is designed for the casual user. It has
 one function, C<check_link>, that returns the HTTP response
 code that it receives when it tries to fetch the web address
-passed to it. The undef value is returned for any failure
+passed to it. The undef value is returned for any non-HTTP failure
 and the C<$HTTP::SimpleLinkChecker::ERROR> variable is
 set.
 
@@ -83,8 +88,44 @@ The HEAD method is tried first, although if anything other than
 a good status code (those less than 400) is received, another
 request is made with the GET method.
 
+=head2 Functions
+
+=over 4
+
+=item check_link( URL )
+
+Return the HTTP response code for URL.
+
+=item user_agent
+
+Returns a reference to the LWP::UserAgent object.  You
+can affect it directly.  See L<LWP::UserAgent>.
+
+	my $ua = HTTP::SimpleLinkChecker::user_agent;
+	$ua->from( 'joe@example.com' );
+	$ua->agent( 'Mozilla 19.2' );
+
+=back
+
+=head1 SOURCE AVAILABILITY
+
+This source is part of a SourceForge project which always has the
+latest sources in CVS, as well as all of the previous releases.
+
+	http://sourceforge.net/projects/brian-d-foy/
+
+If, for some reason, I disappear from the world, one of the other
+members of the project can shepherd this module appropriately.
+
 =head1 AUTHOR
 
-brian d foy <bdfoy@cpan.org>
+brian d foy, C<< <bdfoy@cpan.org> >>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2004 brian d foy.  All rights reserved.
+
+This program is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
